# @(#) makefile for unix and g++

# user name
USER = ichikawa

# directories
OHYMOSLIB = ohymos.lib
OHYMOSDIR = /home/$(USER)/ohymos-lib/ohymos-current
HEADERDIR = /I:$(OHYMOSDIR)
LIBDIR    = /LIBPATH:$(OHYMOSDIR)
LIBS      = $(OHYMOSLIB)
LDFLAG = $(LIBS) /link $(LIBDIR)
OMPFLAG = /Qopenmp
# OMPFLAG = 

# comment out the following line to use nmake.exe
SHELL = /bin/sh

CXX = icl
CXXFLAG = /c /GX $(HEADERDIR) $(OMPFLAG)
OBJ = .obj
EXE = .exe
EXN = 

.SUFFIXES:
.SUFFIXES:	$(OBJ) .cc .lib

.cc$(OBJ):
	$(CXX) $(CXXFLAG) $*.cc

# Automatic variable
#  $@       The file name of the target
#  $<       The name of the first dependency

# ----------------------------------------------------------------------
# The lines below may not depend the operating system
# ----------------------------------------------------------------------

PACKAGENAME = ohsample
BINS	= tsample$(EXE) ohymos$(EXE)
OBJS	= tsample$(OBJ) ksedge$(OBJ) kinem$(OBJ) dfopen$(OBJ)
SRCS	= tsample.cc ksedge.cc ksedge.h kinem.cc kinem.h \
		  dfopen.cc dfopen.h \
		  khboolean.h \
		  khdfstream.cc khdfstream.h kherror.h \
		  mkPmtIst.cc nopath.h
DATA	= tsample.in tsample.ist tsample.pmt \
	  tsample-00.ksist tsample-00.kspmt tsample-00.top \
	  tsample-01.ksist tsample-01.kspmt tsample-01.top \
	  tsample-02.ksist tsample-02.kspmt tsample-02.top
AUXS	= Makefile Makefile.gomp Makefile.icl Makefile.icpc \
          mkPmtIst.mak 00Readme.j.kinem 00Readme.j.ksedge \
          00Readme.j.sample version.no \
          edge_connection_v1.txt edge_connection_v2.txt edge_connection_v3.txt \
          edge_connection_v4.txt edge_connection_v5.txt 
DIRS	= 

SCFOBJS	= ksedge$(OBJ) kinem$(OBJ) newelement$(OBJ) newport$(OBJ) ohymos$(OBJ)
SCFSRCS	= ksedge.cc ksedge.h kinem.cc kinem.h elmlist.h newelement.cc newelement.h \
          newport.cc newport.h ohymos.cc ohymos.h 
SCFDATA = tsamplescf.in tsamplescf.ist tsamplescf.pmt tsamplescf.scf


# @begin{definition-of-COPY} -------------------------------------------

COPY	=

# @end{definition-of-COPY} ---------------------------------------------

all	: $(COPY) $(BINS) $(OBJS)

# @begin{COPY-execution-part} ------------------------------------------

copy	:	$(COPY)

copyclean	:
	-rm $(COPY)

# @end{COPY-execution-part} --------------------------------------------

tsample$(EXE)	:	$(OBJS)
	$(CXX) $(EXN) $(OBJS) $(LDFLAG)

ohymos$(EXE)	:	$(SCFOBJS)
	$(CXX) $(EXN) $(SCFOBJS) $(LDFLAG)

clear	:	clean

clean	:
	-rm -f core *.core *$(OBJ) a.out $(BINS) *-cc.* *-h.*

# @begin{Release-part} -------------------------------------------------

release	: $(SRCS) $(SCFSRCS) $(DATA) $(SCFDATA) $(AUXS) $(DIRS)
	echo $(PACKAGENAME)-`sed \
	     -e '/Revision/!d' \
	     -e 's/[^0-9.]*\([0-9.]*\).*/\1/' \
	     -e q version.no` > .fname
	-rm -rf `cat .fname`
	mkdir `cat .fname`
	cp -fpR $(SRCS) $(SCFSRCS) $(DATA) $(SCFDATA) $(AUXS) $(DIRS) `cat .fname`
	tar czf `cat .fname`.tgz `cat .fname`
	-rm -rf `cat .fname` .fname

# @end{Release-part} ---------------------------------------------------

### Local Variables: ***
### mode: Makefile ***
### indent-tabs-mode: t ***
### tab-width: 8 ***
### End: ***
